==> jetspeed-2-2.2.2-source-release.zip: jetspeed-2-2.2.2/components/jetspeed-profiler/src/main/java/org/apache/jetspeed/profiler/rules/impl/ProfileResolversImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.jetspeed.profiler.rules.impl;

import java.io.Serializable;
import java.util.Map;

import org.apache.jetspeed.profiler.rules.ProfileResolvers;
import org.apache.jetspeed.profiler.rules.RuleCriterionResolver;

/**
 * Profile Resolvers 
 *
 * @author <a href="mailto:taylor@apache.org">David Sean Taylor</a>
 * @version $Id: $
 */
public class ProfileResolversImpl implements ProfileResolvers, Serializable
{
    private Map resolvers;
    
    public ProfileResolversImpl(Map resolvers)
    {
        this.resolvers = resolvers;
    }
    
    public RuleCriterionResolver get(String resolverName)
    {
        return (RuleCriterionResolver)resolvers.get(resolverName);
    }
    
    /**
     * return the map of resolver
     */
    public Map getResolvers()
    {
    	return resolvers;
    }
}

==> jetspeed-2-2.3.0-source-release.zip: jetspeed-2-2.3.0/components/jetspeed-profiler/src/main/java/org/apache/jetspeed/profiler/rules/impl/ProfileResolversImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.jetspeed.profiler.rules.impl;

import org.apache.jetspeed.profiler.rules.ProfileResolvers;
import org.apache.jetspeed.profiler.rules.RuleCriterionResolver;

import java.io.Serializable;
import java.util.Map;

/**
 * Profile Resolvers 
 *
 * @author <a href="mailto:taylor@apache.org">David Sean Taylor</a>
 * @version $Id: $
 */
public class ProfileResolversImpl implements ProfileResolvers, Serializable
{
    private Map<String, RuleCriterionResolver> resolvers;
    
    public ProfileResolversImpl(Map resolvers)
    {
        this.resolvers = resolvers;
    }
    
    public RuleCriterionResolver get(String resolverName)
    {
        return resolvers.get(resolverName);
    }
    
    /**
     * return the map of resolver
     */
    public Map<String, RuleCriterionResolver> getResolvers()
    {
    	return resolvers;
    }
}
